#!/bin/sh

ROOT_FS="/mnt/fs_root"
FILES_BACKUP_FACTORY=""
FILES_BACKUP="etc/network/interfaces etc/resolv.conf $FILES_BACKUP_FACTORY"

TMP_FILE="/tmp/bk.tar"

FACTORY_RESET="true"

setup_wifi() {
	VERSION_FILE="/usr/share/idpr/VERSION"
	CURR_VERSION_NUMBERS=($(cat $VERSION_FILE | tr "." " "))

	WIFI_UPDATE_VERSION_NUMBERS=('1' '1' '4')
	GO="false"
	for i in "${!CURR_VERSION_NUMBERS[@]}"; do
		if [[ ${WIFI_UPDATE_VERSION_NUMBERS[i]} -gt ${CURR_VERSION_NUMBERS[i]} ]]; then
	        GO="true"
	        break
		elif [[ ${WIFI_UPDATE_VERSION_NUMBERS[i]} -lt ${CURR_VERSION_NUMBERS[i]} ]]; then
			break
		fi
	done

	if [ "$GO" == "true" ]; then
		touch /mnt/configuration/NO_WIFI
	fi
}

echo "Setting Wifi..."
setup_wifi
echo "OK"

echo "Updating MAC..."
update-mac dtb_standard.bin dtb_standard.patched
echo "OK"

echo "Erasing DTB Standard... "
flash_eraseall /dev/mtd1
echo "OK"

echo "Flashing DTB Standard... "
nandwrite -p /dev/mtd1 dtb_standard.patched
echo "OK"

echo "Erasing Kernel Standard... "
flash_eraseall /dev/mtd3
echo "OK"

echo "Flashing Kernel Standard... "
nandwrite -p /dev/mtd3 kernel_standard.bin
echo "OK"

echo "Backing up files..."
ROOT_PASSWD=$(egrep -v '.*:\*|:\!' $ROOT_FS/etc/shadow | grep root | awk -F: '{print $2}')
if [ -f "FACTORY_RESET" ]; then
	tar -C $ROOT_FS -c $FILES_BACKUP_FACTORY -f $TMP_FILE
	rm -rf /mnt/fs_user/*
else
	tar -C $ROOT_FS -c $FILES_BACKUP -f $TMP_FILE
fi
echo "OK"

echo "Umounting Root File System..."
umount $ROOT_FS
echo "OK"

echo "Detaching Root File System..."
ubidetach -m 7
echo "OK"

echo "Formating Root File System..."
ubiformat /dev/mtd7 -y -f main.ubi
echo "OK"

echo "Attaching Root File System..."
ubiattach -p /dev/mtd7
echo "OK"

echo "Mounting Root File System..."
mount $ROOT_FS
echo "OK"

echo "Restoring files..."
tar -x -f $TMP_FILE -C $ROOT_FS
FILE_CONTENT=$(awk -F: "BEGIN {OFS=FS;} \$1 == \"root\" {\$2=\"$ROOT_PASSWD\"} 1" $ROOT_FS/etc/shadow)
echo -n "$FILE_CONTENT" > $ROOT_FS/etc/shadow
echo "OK"

echo "Cleanning up..."
rm $TMP_FILE
echo "OK"
